@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-error-viewer-extension.c 1666 2008-01-30 18:17:31Z diegoe $
+ *  $Id$
  */
 
 #include "config.h"
@@ -35,11 +35,7 @@
 #include <epiphany/ephy-embed-container.h>
 #include <epiphany/ephy-embed-shell.h>
 
-#include <gtk/gtkaction.h>
-#include <gtk/gtkactiongroup.h>
-#include <gtk/gtkuimanager.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtknotebook.h>
+#include <gtk/gtk.h>
 
 #include <glib/gi18n-lib.h>
 
@@ -273,7 +269,7 @@ update_actions (EphyWindow *window)
 	EphyEmbed *embed;
 	GtkAction *action1;
 	GtkAction *action2; /* You can tell I didn't want to think... */
-	EphyEmbedDocumentType content_type;
+	EphyEmbedDocumentType content_type = -1;
 	GValue sensitive = { 0, };
 
 	g_return_if_fail (EPHY_IS_WINDOW (window));
@@ -301,10 +297,8 @@ update_actions (EphyWindow *window)
 
 	content_type = ephy_embed_get_document_type (embed);
 
-	if (content_type &&
-            ((content_type == EPHY_EMBED_DOCUMENT_HTML)
+	if ((content_type == EPHY_EMBED_DOCUMENT_HTML)
              || (content_type == EPHY_EMBED_DOCUMENT_XML))
-        )
 	{
 		g_value_set_boolean (&sensitive, TRUE);
 	}
