@@ -16,12 +16,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: sample-mozilla.c,v 1.9 2006/09/13 19:01:31 chpe Exp $
+ *  $Id$
  */
 
 #include "config.h"
 
 #include "ephy-sample2-extension.h"
+#include "mozilla-sample.h"
 #include "ephy-debug.h"
 
 #include <gmodule.h>
@@ -34,10 +35,13 @@ register_module (GTypeModule *module)
 {
 	LOG ("Registering EphySample2Extension");
 
+        if (!mozilla_glue_startup ())
+              return 0;
+
 #ifdef ENABLE_NLS
-       /* Initialise the i18n stuff */
-        bindtextdomain (GETTEXT_PACKAGE, EPHY_EXTENSIONS_LOCALEDIR);
-        bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");	
+	/* Initialise the i18n stuff */
+	bindtextdomain (GETTEXT_PACKAGE, EPHY_EXTENSIONS_LOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 #endif /* ENABLE_NLS */
 
 	return ephy_sample2_extension_register_type (module);
