@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-sidebar-embed.c,v 1.17 2006/09/13 19:01:36 chpe Exp $
+ * $Id$
  */
 
 #include "config.h"
@@ -25,7 +25,6 @@
 
 #include <epiphany/ephy-embed.h>
 #include <epiphany/ephy-shell.h>
-#include <epiphany/ephy-tab.h>
 #include <epiphany/ephy-embed-event.h>
 #include <epiphany/ephy-embed-persist.h>
 #include <epiphany/ephy-embed-factory.h>
@@ -34,11 +33,7 @@
 #include "ephy-prefs.h"
 #include "ephy-debug.h"
 
-#include <gtk/gtkactiongroup.h>
-#include <gtk/gtkuimanager.h>
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkstock.h>
+#include <gtk/gtk.h>
 
 /* NOTE: we include gi18n.h instead of gi18n-lib.h since all string here
  * are the same as in epiphany. If that ever changes, fix this include!
