@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyUtils.h 1376 2006-09-13 19:01:42Z chpe $
+ *  $Id$
  */
 
 #ifndef EPHY_UTILS_H
@@ -28,7 +28,7 @@
 
 #include <nscore.h>
 
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 
 class nsACString;
 class nsAString;
